# -*- coding: utf-8 -*-
"""
Created on Tue Feb  2 19:56:13 2021

@author: -
https://www.postgresqltutorial.com/postgresql-python/connect/
"""
import os
from configparser import ConfigParser


def config(filename='database.ini', section='MySQL'):
    # create a parser
    parser = ConfigParser()
    # read config file
    parser.read(filename)

    # get section, default to postgresql
    db = {}
    if parser.has_section(section):

        params = parser.items(section)
        for param in params:
            db[param[0]] = param[1]
    else:
        raise Exception('Section {0} not found in the {1} file'.format(section, filename))

    return db